@@ -7,21 +7,25 @@ try:
 except ImportError:
     from typing_extensions import Literal
 
-try:
-    from rich.logging import RichHandler
-except ImportError:
-    raise ImportError("pip install exmachina[rich]")
 
-
-def set_verbose(verbose: Literal["DEBUG", "INFO", "WARNING", "ERROR", "CRITICAL"] | None):
+def set_verbose(
+    logger: logging.Logger | None = None,
+    verbose: Literal["DEBUG", "INFO", "WARNING", "ERROR", "CRITICAL"] | None = None,
+):
     """exmachinaのログを表示する
 
     Args:
         verbose (Literal[): 10, 20, 30, 40, 50に相当
     """
+    try:
+        from rich.logging import RichHandler
+    except ModuleNotFoundError:
+        raise ImportError("pip install exmachina[rich]")
+
     if verbose is not None:
         handler = RichHandler(rich_tracebacks=True, enable_link_path=False, level=verbose)
-        logger = logging.getLogger("exmachina")
+        if logger is None:
+            logger = logging.getLogger("exmachina")
         logger.setLevel(verbose)
         if "RichHandler" not in [h.__class__.__name__ for h in logger.handlers]:
             logger.addHandler(handler)
